@@ -7,6 +7,7 @@ from deepcrawl.api import ApiConnection
 from deepcrawl.api.api_endpoints import get_api_endpoint
 from .issues import DeepCrawlIssue
 from .majestic_settings import MajesticSettings
+from .project_settings import ProjectSettings
 from .projects import DeepCrawlProject
 
 
@@ -44,7 +45,8 @@ class ProjectConnection(ApiConnection):
     """
 
     def create_project(self, account_id, project_settings: dict):
-        """Create a project
+        """Create a project.
+        Project settings argument can be dict or a ProjectSettings instance.
 
         .. code-block::
 
@@ -127,11 +129,14 @@ class ProjectConnection(ApiConnection):
 
         :param account_id: account id
         :type account_id: int
-        :param project_settings: project conguration
-        :type project_settings: dict
+        :param project_settings: project configuration
+        :type project_settings: dict or ProjectSettings
         :return: Project instance
         :rtype: DeepCrawlProject
         """
+        if isinstance(project_settings, ProjectSettings):
+            project_settings = project_settings.to_dict
+
         endpoint_url = get_api_endpoint(endpoint='projects', account_id=account_id)
         response = self.dc_request(url=endpoint_url, method='post', json=project_settings)
         return DeepCrawlProject(project_data=response.json(), account_id=account_id)
@@ -154,7 +159,8 @@ class ProjectConnection(ApiConnection):
         return DeepCrawlProject(project_data=response.json(), account_id=account_id)
 
     def update_project_settings(self, account_id, project_id, settings):
-        """Update the project settings
+        """Update the project settings.
+        Settings argument can be dict or a ProjectSettings instance.
 
         >>> connection.update_project_settings(0, 1, settings)
         [0 1] www.test.com Project
@@ -163,11 +169,14 @@ class ProjectConnection(ApiConnection):
         :type account_id: int
         :param project_id: project id
         :type project_id: int
-        :param settings: settings configuration
-        :type settings: dict
+        :param settings: new settings configuration
+        :type settings: dict or ProjectSettings
         :return: Updated project
         :rtype: DeepCrawlProject
         """
+        if isinstance(settings, ProjectSettings):
+            settings = settings.to_dict
+
         endpoint_url = get_api_endpoint(endpoint='project', account_id=account_id, project_id=project_id)
         response = self.dc_request(url=endpoint_url, method='patch', json=settings)
         return DeepCrawlProject(project_data=response.json(), account_id=account_id)
@@ -236,11 +245,12 @@ class ProjectConnection(ApiConnection):
 
     def update_majestic_settings(self, account_id, project_id, majestic_settings):
         """Update majestic settings
+        Majestic settings argument can be dict or a MajesticSettings instance.
 
         .. code-block::
 
             majestic_settings = {
-                "enabled": str,
+                "enabled": bool,
                 "max_rows": int,
                 "use_historic_data": bool,
                 "use_root_domain": bool
@@ -253,10 +263,13 @@ class ProjectConnection(ApiConnection):
         :param project_id: project id
         :type project_id: int
         :param majestic_settings: majestic settings configuration
-        :type majestic_settings: dict
+        :type majestic_settings: dict or MajesticSettings
         :return: updated majestic settings instance
         :rtype: MajesticSettings
         """
+        if isinstance(majestic_settings, MajesticSettings):
+            majestic_settings = majestic_settings.to_dict_mutable_fields
+
         endpoint_url = get_api_endpoint(endpoint='majestic', account_id=account_id, project_id=project_id)
         response = self.dc_request(url=endpoint_url, method='patch', json=majestic_settings)
         return MajesticSettings(majestic_settings=response.json())
