@@ -9,9 +9,17 @@ from deepcrawl.utils import safe_string_to_datetime
 from .extractions import DeepCrawlExtraction
 from .project_settings import ProjectSettings
 
-project_mutable_fields = (
+project_extra_fields = (
     "id",
     "account_id",
+    "project_settings",
+    "majestic_settings",
+    "crawls",
+    "issues",
+    "schedules",
+)
+
+project_mutable_fields = project_extra_fields + (
     "crawls_count",
     "issues_count",
     "next_run_time",
@@ -24,14 +32,6 @@ project_immutable_fields = (
 
 )
 
-project_extra_fields = (
-    "project_settings",
-    "majestic_settings",
-    "crawls",
-    "issues",
-    "schedules",
-)
-
 project_fields = project_mutable_fields + project_immutable_fields + project_extra_fields
 
 
@@ -41,7 +41,7 @@ class DeepCrawlProject(ImmutableAttributesMixin):
     """
     __slots__ = project_fields
 
-    mutable_attributes = project_mutable_fields + project_extra_fields
+    mutable_attributes = project_mutable_fields
 
     def __init__(self, project_data, account_id):
         # relations
@@ -80,10 +80,16 @@ class DeepCrawlProject(ImmutableAttributesMixin):
 
     @property
     def to_dict(self):
+        """
+        :return: dictionary with the project fields
+        :rtype: dict
+        """
         dict_ = super(DeepCrawlProject, self).to_dict
 
         # Remove extra fields
         for attr in project_extra_fields:
+            if attr in ["id", "account_id"]:
+                continue
             dict_.pop(attr)
 
         dict_.update(**self.project_settings.to_dict)
@@ -91,6 +97,22 @@ class DeepCrawlProject(ImmutableAttributesMixin):
 
         return dict_
 
+    @property
+    def to_dict_mutable_fields(self):
+        """
+        :return: dictionary with the mutable fields
+        :rtype: dict
+        """
+        return {x: getattr(self, x, None) for x in project_mutable_fields}
+
+    @property
+    def to_dict_immutable_fields(self):
+        """
+        :return: dictionary with the immutable fields
+        :rtype: dict
+        """
+        return {x: getattr(self, x, None) for x in project_immutable_fields}
+
     def load_crawls(self, connection=None, filters=None, **kwargs):
         """Loads crawls into current instance
 
@@ -201,13 +223,14 @@ class DeepCrawlProject(ImmutableAttributesMixin):
         return self
 
     def update_settings(self, project_settings, connection=None):
-        """Updates current instance with project_settings
+        """Updates current project instance with another project_settings.
+        Settings argument can be dict or a ProjectSettings instance.
 
         >>> self.update_settings(project_settings)
         [0 1] www.test.com Project Updated
 
-        :param project_settings: dictionary with the new configuration
-        :type project_settings: dict
+        :param project_settings: new settings configuration
+        :type project_settings: dict or ProjectSettings
         :param connection: connection
         :type connection: deepcrawl.DeepCrawlConnection
 
@@ -216,7 +239,7 @@ class DeepCrawlProject(ImmutableAttributesMixin):
         """
         connection = connection or deepcrawl.DeepCrawlConnection.get_instance()
         project = connection.update_project_settings(self.account_id, self.id, project_settings)
-        self.project_settings = project.project_setting
+        self.project_settings = project.project_settings
         return self
 
     def delete(self, connection=None):
@@ -233,8 +256,8 @@ class DeepCrawlProject(ImmutableAttributesMixin):
         response = connection.delete_project(self.account_id, self.id)
         return response
 
-    def add_extractions(self, connection, extractions):
-        """Add extraction to current project
+    def add_extractions(self, extractions, connection=None):
+        """Add extractions to current project
 
         .. code-block::
 
@@ -253,24 +276,23 @@ class DeepCrawlProject(ImmutableAttributesMixin):
 
         :param connection: connection
         :type connection: deepcrawl.DeepCrawlConnection
-        :param extractions: extractions to add
+        :param extractions: list of dictionaries or list of DeepCrawlExtraction instances or combined
         :type extractions: list
         :return: project with updated extractions
         :rtype: DeepCrawlProject
         """
-        self.custom_extractions.extend(extractions)
+        connection = connection or deepcrawl.DeepCrawlConnection.get_instance()
+        extractions_list = ([x.to_dict for x in self.custom_extractions])
 
-        custom_extractions_list = []
-        for custom_extraction in self.custom_extractions:
-            custom_extractions_list.append({
-                'label': custom_extraction.label,
-                'regex': custom_extraction.regex,
-                'match_number_from': custom_extraction.match_number_from,
-                'match_number_to': custom_extraction.match_number_to,
-                'filter': custom_extraction.filter,
-                'clean_html_tags': custom_extraction.clean_html_tags
-            })
-        new_settings = {'custom_extractions': custom_extractions_list}
+        for extraction in extractions:
+            if isinstance(extraction, DeepCrawlExtraction):
+                extractions_list.append(extraction.to_dict)
+                self.custom_extractions.append(extraction)
+            else:
+                extractions_list.append(extraction)
+                self.custom_extractions.append(DeepCrawlExtraction(extraction_data=extraction))
+
+        new_settings = {'custom_extractions': extractions_list}
         return connection.update_project_settings(self.account_id, self.id, new_settings)
 
     """
@@ -290,7 +312,8 @@ class DeepCrawlProject(ImmutableAttributesMixin):
         :rtype: MajesticSettings
         """
         connection = connection or deepcrawl.DeepCrawlConnection.get_instance()
-        return connection.get_majestic_settings(self.account_id, self.id)
+        self.majestic_settings = connection.get_majestic_settings(self.account_id, self.id)
+        return self.majestic_settings
 
     def refresh_majestic_settings(self, connection=None):
         """Refresh majestic settings
@@ -309,7 +332,8 @@ class DeepCrawlProject(ImmutableAttributesMixin):
         return self.majestic_settings
 
     def update_majestic_settings(self, majestic_settings, connection=None):
-        """Update majestic settings
+        """Update majestic settings.
+        Majestic settings argument can be dict or a MajesticSettings instance.
 
         >>> self.update_majestic_settings(majestic_settings)
         [<deepcrawl.projects.majestic_settings.MajesticSettings at 0x108a20600>,
@@ -318,9 +342,9 @@ class DeepCrawlProject(ImmutableAttributesMixin):
         :param connection: connection
         :type connection: deepcrawl.DeepCrawlConnection
         :param majestic_settings: majestic settings
-        :type majestic_settings:
-        :return: refreshed majestic settings
-        :rtype: list
+        :type majestic_settings: dict or MajesticSettings
+        :return: updated majestic settings
+        :rtype: MajesticSettings
         """
         connection = connection or deepcrawl.DeepCrawlConnection.get_instance()
         self.majestic_settings = connection.update_majestic_settings(self.account_id, self.id, majestic_settings)
